CountdownText class
A Flutter widget that counts down to a target DateTime and automatically updates every second.
CountdownText(
target: event.startsAt,
format: '{d}d {h}h {m}m {s}s',
style: TextStyle(color: Colors.red, fontWeight: FontWeight.bold),
onFinished: () => print('Event started!'),
)
Format tokens:
{d}→ days remaining{h}→ hours (0–23){m}→ minutes (0–59){s}→ seconds (0–59){hh}→ hours with leading zero{mm}→ minutes with leading zero{ss}→ seconds with leading zero
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CountdownText
Constructors
- CountdownText({Key? key, required DateTime target, String format = '{h}:{mm}:{ss}', TextStyle? style, TextAlign? textAlign, VoidCallback? onFinished, String finishedText = 'Started!', bool showZeroDays = false})
-
Creates a CountdownText widget.
const
Properties
- finishedText → String
-
Text to show when countdown finishes
final
- format → String
-
Format string using tokens: {d}, {h}, {m}, {s}, {hh}, {mm}, {ss}
Default: '{h}:{mm}:{ss}'
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onFinished → VoidCallback?
-
Called when countdown reaches zero
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showZeroDays → bool
-
Whether to show days when 0
final
- style → TextStyle?
-
Text style
final
- target → DateTime
-
Target date to count down to
final
- textAlign → TextAlign?
-
Text align
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CountdownText> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited